import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { Agent } from '../model/agent';
import { AgentBasic } from '../model/agentBasic';
import { AgentSearchFilter } from '../model/agentSearchFilter';
import { AgentSearchResult } from '../model/agentSearchResult';
import { Configuration } from '../configuration';
export declare class MtcAgentControllerService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * bulkAgentBasicData
     *
     * @param idAgentList idAgentList
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    bulkAgentBasicDataUsingGET(idAgentList: Array<number>, observe?: 'body', reportProgress?: boolean): Observable<Array<AgentBasic>>;
    bulkAgentBasicDataUsingGET(idAgentList: Array<number>, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<AgentBasic>>>;
    bulkAgentBasicDataUsingGET(idAgentList: Array<number>, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<AgentBasic>>>;
    /**
     * getAgentBasicData
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAgentBasicDataUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<AgentBasic>;
    getAgentBasicDataUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<AgentBasic>>;
    getAgentBasicDataUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<AgentBasic>>;
    /**
     * getAgentDetailData
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getAgentDetailDataUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Agent>;
    getAgentDetailDataUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Agent>>;
    getAgentDetailDataUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Agent>>;
    /**
     * searchAgentsUsingFilter
     *
     * @param filter filter
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchAgentsUsingFilterUsingPOST(filter: AgentSearchFilter, observe?: 'body', reportProgress?: boolean): Observable<Array<AgentSearchResult>>;
    searchAgentsUsingFilterUsingPOST(filter: AgentSearchFilter, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<AgentSearchResult>>>;
    searchAgentsUsingFilterUsingPOST(filter: AgentSearchFilter, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<AgentSearchResult>>>;
}
