import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { Beneficiary } from '../model/beneficiary';
import { CreateCustomerRequest } from '../model/createCustomerRequest';
import { Customer } from '../model/customer';
import { CustomerBasicData } from '../model/customerBasicData';
import { CustomerEssentialData } from '../model/customerEssentialData';
import { Note } from '../model/note';
import { NoteCreation } from '../model/noteCreation';
import { PaginatedResultSearchCustomerResponse } from '../model/paginatedResultSearchCustomerResponse';
import { SearchCustomerRequest } from '../model/searchCustomerRequest';
import { TheFullIdentityDocumentInformation } from '../model/theFullIdentityDocumentInformation';
import { TheIdentityDocument } from '../model/theIdentityDocument';
import { UpdateCustomerRequest } from '../model/updateCustomerRequest';
import { Configuration } from '../configuration';
export declare class MtcCustomerControllerService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * createCustomerIdentityDocumentFile
     *
     * @param id id
     * @param idDoc idDoc
     * @param file file
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createCustomerIdentityDocumentFileUsingPOST(id: number, idDoc: number, file: Blob, observe?: 'body', reportProgress?: boolean): Observable<string>;
    createCustomerIdentityDocumentFileUsingPOST(id: number, idDoc: number, file: Blob, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<string>>;
    createCustomerIdentityDocumentFileUsingPOST(id: number, idDoc: number, file: Blob, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<string>>;
    /**
     * createCustomerIdentityDocument
     *
     * @param id id
     * @param identityDocumentDetail identityDocumentDetail
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createCustomerIdentityDocumentUsingPOST(id: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createCustomerIdentityDocumentUsingPOST(id: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createCustomerIdentityDocumentUsingPOST(id: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * createCustomerNote
     *
     * @param id id
     * @param creationNote creationNote
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createCustomerNoteUsingPOST(id: number, creationNote: NoteCreation, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createCustomerNoteUsingPOST(id: number, creationNote: NoteCreation, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createCustomerNoteUsingPOST(id: number, creationNote: NoteCreation, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * createCustomer
     *
     * @param request request
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createCustomerUsingPOST(request: CreateCustomerRequest, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createCustomerUsingPOST(request: CreateCustomerRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createCustomerUsingPOST(request: CreateCustomerRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * getCustomerEssentialDataByIds
     *
     * @param ids ids
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerEssentialDataByIdsUsingGET(ids: Array<number>, observe?: 'body', reportProgress?: boolean): Observable<Array<CustomerEssentialData>>;
    getCustomerEssentialDataByIdsUsingGET(ids: Array<number>, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<CustomerEssentialData>>>;
    getCustomerEssentialDataByIdsUsingGET(ids: Array<number>, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<CustomerEssentialData>>>;
    /**
     * getCustomerEssentialData
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerEssentialDataUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<CustomerBasicData>;
    getCustomerEssentialDataUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CustomerBasicData>>;
    getCustomerEssentialDataUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CustomerBasicData>>;
    /**
     * getCustomerFullData
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerFullDataUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Customer>;
    getCustomerFullDataUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Customer>>;
    getCustomerFullDataUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Customer>>;
    /**
     * getCustomerIdentityDocumentById
     *
     * @param id id
     * @param idDoc idDoc
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerIdentityDocumentByIdUsingGET(id: number, idDoc: number, observe?: 'body', reportProgress?: boolean): Observable<TheIdentityDocument>;
    getCustomerIdentityDocumentByIdUsingGET(id: number, idDoc: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TheIdentityDocument>>;
    getCustomerIdentityDocumentByIdUsingGET(id: number, idDoc: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TheIdentityDocument>>;
    /**
     * getCustomerIdentityDocumentFileById
     *
     * @param id id
     * @param idDoc idDoc
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerIdentityDocumentFileByIdUsingGET(id: number, idDoc: number, observe?: 'body', reportProgress?: boolean): Observable<string>;
    getCustomerIdentityDocumentFileByIdUsingGET(id: number, idDoc: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<string>>;
    getCustomerIdentityDocumentFileByIdUsingGET(id: number, idDoc: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<string>>;
    /**
     * getCustomerIdentityDocuments
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCustomerIdentityDocumentsUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Array<TheIdentityDocument>>;
    getCustomerIdentityDocumentsUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<TheIdentityDocument>>>;
    getCustomerIdentityDocumentsUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<TheIdentityDocument>>>;
    /**
     * searchBeneficiariesByOwner
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchBeneficiariesByOwnerUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Beneficiary>>;
    searchBeneficiariesByOwnerUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Beneficiary>>>;
    searchBeneficiariesByOwnerUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Beneficiary>>>;
    /**
     * searchCustomers
     *
     * @param request request
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchCustomersUsingPOST(request: SearchCustomerRequest, observe?: 'body', reportProgress?: boolean): Observable<PaginatedResultSearchCustomerResponse>;
    searchCustomersUsingPOST(request: SearchCustomerRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<PaginatedResultSearchCustomerResponse>>;
    searchCustomersUsingPOST(request: SearchCustomerRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<PaginatedResultSearchCustomerResponse>>;
    /**
     * searchNotesByCustomerId
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchNotesByCustomerIdUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Note>>;
    searchNotesByCustomerIdUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Note>>>;
    searchNotesByCustomerIdUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Note>>>;
    /**
     * updateCustomerIdentityDocument
     *
     * @param id id
     * @param idDoc idDoc
     * @param identityDocumentDetail identityDocumentDetail
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updateCustomerIdentityDocumentUsingPUT(id: number, idDoc: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'body', reportProgress?: boolean): Observable<number>;
    updateCustomerIdentityDocumentUsingPUT(id: number, idDoc: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    updateCustomerIdentityDocumentUsingPUT(id: number, idDoc: number, identityDocumentDetail: TheFullIdentityDocumentInformation, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * updateCustomer
     *
     * @param id id
     * @param request request
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updateCustomerUsingPUT(id: number, request: UpdateCustomerRequest, observe?: 'body', reportProgress?: boolean): Observable<number>;
    updateCustomerUsingPUT(id: number, request: UpdateCustomerRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    updateCustomerUsingPUT(id: number, request: UpdateCustomerRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
}
