import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { CountryZone } from '../model/countryZone';
import { CreatePolicy } from '../model/createPolicy';
import { CreateRule } from '../model/createRule';
import { Policy } from '../model/policy';
import { Rule } from '../model/rule';
import { RuleParamDescriptor } from '../model/ruleParamDescriptor';
import { Configuration } from '../configuration';
export declare class MtcPricingControllerService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * addCountryZoneMembersBySchemeAndId
     *
     * @param scheme scheme
     * @param id id
     * @param iso iso
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    addCountryZoneMembersBySchemeAndIdUsingPOST(scheme: string, id: number, iso: string, observe?: 'body', reportProgress?: boolean): Observable<any>;
    addCountryZoneMembersBySchemeAndIdUsingPOST(scheme: string, id: number, iso: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    addCountryZoneMembersBySchemeAndIdUsingPOST(scheme: string, id: number, iso: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * createPolicyBySchemeAndRuleId
     *
     * @param scheme scheme
     * @param ruleId ruleId
     * @param policy policy
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createPolicyBySchemeAndRuleIdUsingPOST(scheme: string, ruleId: number, policy: CreatePolicy, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createPolicyBySchemeAndRuleIdUsingPOST(scheme: string, ruleId: number, policy: CreatePolicy, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createPolicyBySchemeAndRuleIdUsingPOST(scheme: string, ruleId: number, policy: CreatePolicy, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * createRuleBySchemeAndTypeAndCcy
     *
     * @param scheme scheme
     * @param type type
     * @param localCcy localCcy
     * @param createRule createRule
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createRuleBySchemeAndTypeAndCcyUsingPOST(scheme: string, type: string, localCcy: string, createRule: CreateRule, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createRuleBySchemeAndTypeAndCcyUsingPOST(scheme: string, type: string, localCcy: string, createRule: CreateRule, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createRuleBySchemeAndTypeAndCcyUsingPOST(scheme: string, type: string, localCcy: string, createRule: CreateRule, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * deleteCountryZoneMembersBySchemeAndId
     *
     * @param scheme scheme
     * @param id id
     * @param iso iso
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteCountryZoneMembersBySchemeAndIdUsingDELETE(scheme: string, id: number, iso: string, observe?: 'body', reportProgress?: boolean): Observable<any>;
    deleteCountryZoneMembersBySchemeAndIdUsingDELETE(scheme: string, id: number, iso: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    deleteCountryZoneMembersBySchemeAndIdUsingDELETE(scheme: string, id: number, iso: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * deletePolicyBySchemeAndId
     *
     * @param scheme scheme
     * @param ruleId ruleId
     * @param policyId policyId
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deletePolicyBySchemeAndIdUsingDELETE(scheme: string, ruleId: number, policyId: number, observe?: 'body', reportProgress?: boolean): Observable<any>;
    deletePolicyBySchemeAndIdUsingDELETE(scheme: string, ruleId: number, policyId: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    deletePolicyBySchemeAndIdUsingDELETE(scheme: string, ruleId: number, policyId: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * deleteRuleBySchemaAndId
     *
     * @param scheme scheme
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    deleteRuleBySchemaAndIdUsingDELETE(scheme: string, id: number, observe?: 'body', reportProgress?: boolean): Observable<any>;
    deleteRuleBySchemaAndIdUsingDELETE(scheme: string, id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    deleteRuleBySchemaAndIdUsingDELETE(scheme: string, id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * getCountryZoneBySchemeAndId
     *
     * @param scheme scheme
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCountryZoneBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'body', reportProgress?: boolean): Observable<CountryZone>;
    getCountryZoneBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CountryZone>>;
    getCountryZoneBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CountryZone>>;
    /**
     * getCountryZoneMembersByBySchemeAndId
     *
     * @param scheme scheme
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCountryZoneMembersByBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'body', reportProgress?: boolean): Observable<Array<string>>;
    getCountryZoneMembersByBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<string>>>;
    getCountryZoneMembersByBySchemeAndIdUsingGET(scheme: string, id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<string>>>;
    /**
     * getCountryZonesBySchemeAndTypeOfRule
     *
     * @param scheme scheme
     * @param type type
     * @param internal internal
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCountryZonesBySchemeAndTypeOfRuleUsingGET(scheme: string, type: string, internal?: boolean, observe?: 'body', reportProgress?: boolean): Observable<Array<CountryZone>>;
    getCountryZonesBySchemeAndTypeOfRuleUsingGET(scheme: string, type: string, internal?: boolean, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<CountryZone>>>;
    getCountryZonesBySchemeAndTypeOfRuleUsingGET(scheme: string, type: string, internal?: boolean, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<CountryZone>>>;
    /**
     * getPoliciesBySchemeAndRuleId
     *
     * @param scheme scheme
     * @param ruleId ruleId
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getPoliciesBySchemeAndRuleIdUsingGET(scheme: string, ruleId: number, observe?: 'body', reportProgress?: boolean): Observable<Array<Policy>>;
    getPoliciesBySchemeAndRuleIdUsingGET(scheme: string, ruleId: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Policy>>>;
    getPoliciesBySchemeAndRuleIdUsingGET(scheme: string, ruleId: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Policy>>>;
    /**
     * getRuleBySchemeAnRuleTypeAndCcy
     *
     * @param scheme scheme
     * @param type type
     * @param localCcy localCcy
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getRuleBySchemeAnRuleTypeAndCcyUsingGET(scheme: string, type: string, localCcy: string, observe?: 'body', reportProgress?: boolean): Observable<Array<Rule>>;
    getRuleBySchemeAnRuleTypeAndCcyUsingGET(scheme: string, type: string, localCcy: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<Rule>>>;
    getRuleBySchemeAnRuleTypeAndCcyUsingGET(scheme: string, type: string, localCcy: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<Rule>>>;
    /**
     * getRuleScheme
     *
     * @param scheme scheme
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getRuleSchemeUsingGET(scheme: string, observe?: 'body', reportProgress?: boolean): Observable<Array<RuleParamDescriptor>>;
    getRuleSchemeUsingGET(scheme: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<RuleParamDescriptor>>>;
    getRuleSchemeUsingGET(scheme: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<RuleParamDescriptor>>>;
    /**
     * updatePolicyBySchemeAndRuleId
     *
     * @param scheme scheme
     * @param ruleId ruleId
     * @param policyId policyId
     * @param policy policy
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updatePolicyBySchemeAndRuleIdUsingPUT(scheme: string, ruleId: number, policyId: number, policy: CreatePolicy, observe?: 'body', reportProgress?: boolean): Observable<any>;
    updatePolicyBySchemeAndRuleIdUsingPUT(scheme: string, ruleId: number, policyId: number, policy: CreatePolicy, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    updatePolicyBySchemeAndRuleIdUsingPUT(scheme: string, ruleId: number, policyId: number, policy: CreatePolicy, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
}
