import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs/Observable';
import { FullTransferDetails } from '../model/fullTransferDetails';
import { PaginatedResultComposedTransferBasicInfo } from '../model/paginatedResultComposedTransferBasicInfo';
import { SearchRequest } from '../model/searchRequest';
import { TransferBlockRequest } from '../model/transferBlockRequest';
import { TransferNote } from '../model/transferNote';
import { TransferNoteCreation } from '../model/transferNoteCreation';
import { TransferReleaseRequest } from '../model/transferReleaseRequest';
import { Configuration } from '../configuration';
export declare class MtcTransferServiceControllerService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes);
    /**
     * blockTransfer
     *
     * @param idTransfer idTransfer
     * @param transferBlockRequest transferBlockRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    blockTransferUsingPOST(idTransfer: number, transferBlockRequest: TransferBlockRequest, observe?: 'body', reportProgress?: boolean): Observable<any>;
    blockTransferUsingPOST(idTransfer: number, transferBlockRequest: TransferBlockRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    blockTransferUsingPOST(idTransfer: number, transferBlockRequest: TransferBlockRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * createTransferNote
     *
     * @param id id
     * @param creationNote creationNote
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createTransferNoteUsingPOST(id: number, creationNote: TransferNoteCreation, observe?: 'body', reportProgress?: boolean): Observable<number>;
    createTransferNoteUsingPOST(id: number, creationNote: TransferNoteCreation, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<number>>;
    createTransferNoteUsingPOST(id: number, creationNote: TransferNoteCreation, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<number>>;
    /**
     * getTransferDetails
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransferDetailsUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<FullTransferDetails>;
    getTransferDetailsUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<FullTransferDetails>>;
    getTransferDetailsUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<FullTransferDetails>>;
    /**
     * releaseTransfer
     *
     * @param idTransfer idTransfer
     * @param transferReleaseRequest transferReleaseRequest
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    releaseTransferUsingPOST(idTransfer: number, transferReleaseRequest: TransferReleaseRequest, observe?: 'body', reportProgress?: boolean): Observable<any>;
    releaseTransferUsingPOST(idTransfer: number, transferReleaseRequest: TransferReleaseRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<any>>;
    releaseTransferUsingPOST(idTransfer: number, transferReleaseRequest: TransferReleaseRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<any>>;
    /**
     * searchNotesByTransferId
     *
     * @param id id
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchNotesByTransferIdUsingGET(id: number, observe?: 'body', reportProgress?: boolean): Observable<Array<TransferNote>>;
    searchNotesByTransferIdUsingGET(id: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<Array<TransferNote>>>;
    searchNotesByTransferIdUsingGET(id: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<Array<TransferNote>>>;
    /**
     * searchTransfers
     *
     * @param filter filter
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    searchTransfersUsingPOST(filter: SearchRequest, observe?: 'body', reportProgress?: boolean): Observable<PaginatedResultComposedTransferBasicInfo>;
    searchTransfersUsingPOST(filter: SearchRequest, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<PaginatedResultComposedTransferBasicInfo>>;
    searchTransfersUsingPOST(filter: SearchRequest, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<PaginatedResultComposedTransferBasicInfo>>;
}
