import { InjectionToken, Inject, Injectable, Optional, NgModule, SkipSelf } from '@angular/core';
import { HttpClient, HttpHeaders, HttpUrlEncodingCodec, HttpParams } from '@angular/common/http';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const BASE_PATH = new InjectionToken('basePath');
const COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

class Configuration {
    /**
     * @param {?=} configurationParameters
     */
    constructor(configurationParameters = {}) {
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    /**
     * Select the correct content-type to use for a request.
     * Uses {\@link Configuration#isJsonMime} to determine the correct content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param {?} contentTypes - the array of content types that are available for selection
     * @return {?} the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderContentType(contentTypes) {
        if (contentTypes.length == 0) {
            return undefined;
        }
        let /** @type {?} */ type = contentTypes.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    }
    /**
     * Select the correct accept content-type to use for a request.
     * Uses {\@link Configuration#isJsonMime} to determine the correct accept content-type.
     * If no content type is found return the first found type if the contentTypes is not empty
     * @param {?} accepts - the array of content types that are available for selection.
     * @return {?} the selected content-type or <code>undefined</code> if no selection could be made.
     */
    selectHeaderAccept(accepts) {
        if (accepts.length == 0) {
            return undefined;
        }
        let /** @type {?} */ type = accepts.find(x => this.isJsonMime(x));
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    }
    /**
     * Check if the given MIME is a JSON MIME.
     * JSON MIME examples:
     *   application/json
     *   application/json; charset=UTF8
     *   APPLICATION/JSON
     *   application/vnd.company+json
     * @param {?} mime - MIME (Multipurpose Internet Mail Extensions)
     * @return {?} True if the given MIME is JSON, false otherwise.
     */
    isJsonMime(mime) {
        const /** @type {?} */ jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcAgentControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} idAgentList
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    bulkAgentBasicDataUsingGET(idAgentList, observe = 'body', reportProgress = false) {
        if (idAgentList === null || idAgentList === undefined) {
            throw new Error('Required parameter idAgentList was null or undefined when calling bulkAgentBasicDataUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.get(`${this.basePath}/agents/basic`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getAgentBasicDataUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getAgentBasicDataUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/agents/${encodeURIComponent(String(id))}/basic`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getAgentDetailDataUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getAgentDetailDataUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/agents/${encodeURIComponent(String(id))}/detail`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} filter
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchAgentsUsingFilterUsingPOST(filter, observe = 'body', reportProgress = false) {
        if (filter === null || filter === undefined) {
            throw new Error('Required parameter filter was null or undefined when calling searchAgentsUsingFilterUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/agents/search`, filter, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcAgentControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcAgentControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * CustomHttpUrlEncodingCodec
 * Fix plus sign (+) not encoding, so sent as blank space
 * See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
 */
class CustomHttpUrlEncodingCodec extends HttpUrlEncodingCodec {
    /**
     * @param {?} k
     * @return {?}
     */
    encodeKey(k) {
        k = super.encodeKey(k);
        return k.replace(/\+/gi, '%2B');
    }
    /**
     * @param {?} v
     * @return {?}
     */
    encodeValue(v) {
        v = super.encodeValue(v);
        return v.replace(/\+/gi, '%2B');
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcCustomerControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} id
     * @param {?} idDoc
     * @param {?} file
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createCustomerIdentityDocumentFileUsingPOST(id, idDoc, file, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        if (file === null || file === undefined) {
            throw new Error('Required parameter file was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'multipart/form-data'
        ];
        const /** @type {?} */ canConsumeForm = this.canConsumeForm(consumes);
        let /** @type {?} */ formParams;
        let /** @type {?} */ useForm = false;
        let /** @type {?} */ convertFormParamsToString = false;
        // use FormData to transmit files using content-type "multipart/form-data"
        // see https://stackoverflow.com/questions/4007969/application-x-www-form-urlencoded-or-multipart-form-data
        useForm = canConsumeForm;
        if (useForm) {
            formParams = new FormData();
        }
        else {
            formParams = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        }
        if (file !== undefined) {
            formParams = formParams.append('file', /** @type {?} */ (file)) || formParams;
        }
        return this.httpClient.post(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc/${encodeURIComponent(String(idDoc))}/file`, convertFormParamsToString ? formParams.toString() : formParams, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} identityDocumentDetail
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createCustomerIdentityDocumentUsingPOST(id, identityDocumentDetail, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerIdentityDocumentUsingPOST.');
        }
        if (identityDocumentDetail === null || identityDocumentDetail === undefined) {
            throw new Error('Required parameter identityDocumentDetail was null or undefined when calling createCustomerIdentityDocumentUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc`, identityDocumentDetail, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} creationNote
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createCustomerNoteUsingPOST(id, creationNote, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createCustomerNoteUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/customer/${encodeURIComponent(String(id))}/note`, creationNote, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} request
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createCustomerUsingPOST(request, observe = 'body', reportProgress = false) {
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling createCustomerUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/customer`, request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} ids
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerEssentialDataByIdsUsingGET(ids, observe = 'body', reportProgress = false) {
        if (ids === null || ids === undefined) {
            throw new Error('Required parameter ids was null or undefined when calling getCustomerEssentialDataByIdsUsingGET.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (ids) {
            ids.forEach((element) => {
                queryParameters = queryParameters.append('ids', /** @type {?} */ (element));
            });
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer${encodeURIComponent(String(ids))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerEssentialDataUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerEssentialDataUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/essential`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerFullDataUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerFullDataUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/full`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} idDoc
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerIdentityDocumentByIdUsingGET(id, idDoc, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentByIdUsingGET.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling getCustomerIdentityDocumentByIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc/${encodeURIComponent(String(idDoc))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} idDoc
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerIdentityDocumentFileByIdUsingGET(id, idDoc, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentFileByIdUsingGET.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling getCustomerIdentityDocumentFileByIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc/${encodeURIComponent(String(idDoc))}/file`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCustomerIdentityDocumentsUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentsUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchBeneficiariesByOwnerUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchBeneficiariesByOwnerUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/beneficiaries`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} request
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchCustomersUsingPOST(request, observe = 'body', reportProgress = false) {
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling searchCustomersUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/customer/search`, request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchNotesByCustomerIdUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchNotesByCustomerIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/customer/${encodeURIComponent(String(id))}/note`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} idDoc
     * @param {?} identityDocumentDetail
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    updateCustomerIdentityDocumentUsingPUT(id, idDoc, identityDocumentDetail, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        if (identityDocumentDetail === null || identityDocumentDetail === undefined) {
            throw new Error('Required parameter identityDocumentDetail was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/customer/${encodeURIComponent(String(id))}/idDoc/${encodeURIComponent(String(idDoc))}`, identityDocumentDetail, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} request
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    updateCustomerUsingPUT(id, request, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling updateCustomerUsingPUT.');
        }
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling updateCustomerUsingPUT.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/customer/${encodeURIComponent(String(id))}`, request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcCustomerControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcCustomerControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcGsGeolocationControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} idCity
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCityByIdUsingGET(idCity, observe = 'body', reportProgress = false) {
        if (idCity === null || idCity === undefined) {
            throw new Error('Required parameter idCity was null or undefined when calling getCityByIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/geo/city/${encodeURIComponent(String(idCity))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} country
     * @param {?} cityName
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchCityByCountryAndNameUsingGET(country, cityName, observe = 'body', reportProgress = false) {
        if (country === null || country === undefined) {
            throw new Error('Required parameter country was null or undefined when calling searchCityByCountryAndNameUsingGET.');
        }
        if (cityName === null || cityName === undefined) {
            throw new Error('Required parameter cityName was null or undefined when calling searchCityByCountryAndNameUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/geo/city/${encodeURIComponent(String(country))}/${encodeURIComponent(String(cityName))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcGsGeolocationControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcGsGeolocationControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcNotesControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} owner
     * @param {?} creationNote
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createNoteUsingPOST(owner, creationNote, observe = 'body', reportProgress = false) {
        if (owner === null || owner === undefined) {
            throw new Error('Required parameter owner was null or undefined when calling createNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createNoteUsingPOST.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (owner !== undefined && owner !== null) {
            queryParameters = queryParameters.set('owner', /** @type {?} */ (owner));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/note${encodeURIComponent(String(owner))}`, creationNote, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} owner
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchNotesByOwnerUsingGET(owner, observe = 'body', reportProgress = false) {
        if (owner === null || owner === undefined) {
            throw new Error('Required parameter owner was null or undefined when calling searchNotesByOwnerUsingGET.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (owner !== undefined && owner !== null) {
            queryParameters = queryParameters.set('owner', /** @type {?} */ (owner));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/note/search`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcNotesControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcNotesControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcPricingControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} scheme
     * @param {?} id
     * @param {?} iso
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    addCountryZoneMembersBySchemeAndIdUsingPOST(scheme, id, iso, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        if (iso === null || iso === undefined) {
            throw new Error('Required parameter iso was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.post(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/country-zones/${encodeURIComponent(String(id))}/members/${encodeURIComponent(String(iso))}`, null, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} ruleId
     * @param {?} policy
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createPolicyBySchemeAndRuleIdUsingPOST(scheme, ruleId, policy, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        if (policy === null || policy === undefined) {
            throw new Error('Required parameter policy was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/${encodeURIComponent(String(ruleId))}/policies`, policy, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} type
     * @param {?} localCcy
     * @param {?} createRule
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createRuleBySchemeAndTypeAndCcyUsingPOST(scheme, type, localCcy, createRule, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (localCcy === null || localCcy === undefined) {
            throw new Error('Required parameter localCcy was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (createRule === null || createRule === undefined) {
            throw new Error('Required parameter createRule was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/types/${encodeURIComponent(String(type))}/ccy/${encodeURIComponent(String(localCcy))}`, createRule, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} id
     * @param {?} iso
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    deleteCountryZoneMembersBySchemeAndIdUsingDELETE(scheme, id, iso, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        if (iso === null || iso === undefined) {
            throw new Error('Required parameter iso was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.delete(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/country-zones/${encodeURIComponent(String(id))}/members/${encodeURIComponent(String(iso))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} ruleId
     * @param {?} policyId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    deletePolicyBySchemeAndIdUsingDELETE(scheme, ruleId, policyId, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        if (policyId === null || policyId === undefined) {
            throw new Error('Required parameter policyId was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.delete(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/${encodeURIComponent(String(ruleId))}/policies/${encodeURIComponent(String(policyId))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    deleteRuleBySchemaAndIdUsingDELETE(scheme, id, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deleteRuleBySchemaAndIdUsingDELETE.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRuleBySchemaAndIdUsingDELETE.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.delete(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCountryZoneBySchemeAndIdUsingGET(scheme, id, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZoneBySchemeAndIdUsingGET.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCountryZoneBySchemeAndIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/country-zones/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCountryZoneMembersByBySchemeAndIdUsingGET(scheme, id, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZoneMembersByBySchemeAndIdUsingGET.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCountryZoneMembersByBySchemeAndIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/country-zones/${encodeURIComponent(String(id))}/members`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} type
     * @param {?=} internal
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getCountryZonesBySchemeAndTypeOfRuleUsingGET(scheme, type, internal, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZonesBySchemeAndTypeOfRuleUsingGET.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling getCountryZonesBySchemeAndTypeOfRuleUsingGET.');
        }
        let /** @type {?} */ queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (internal !== undefined && internal !== null) {
            queryParameters = queryParameters.set('internal', /** @type {?} */ (internal));
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/country-zones/rule-type/${encodeURIComponent(String(type))}${encodeURIComponent(String(internal))}`, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} ruleId
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getPoliciesBySchemeAndRuleIdUsingGET(scheme, ruleId, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getPoliciesBySchemeAndRuleIdUsingGET.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling getPoliciesBySchemeAndRuleIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/${encodeURIComponent(String(ruleId))}/policies`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} type
     * @param {?} localCcy
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getRuleBySchemeAnRuleTypeAndCcyUsingGET(scheme, type, localCcy, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        if (localCcy === null || localCcy === undefined) {
            throw new Error('Required parameter localCcy was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/types/${encodeURIComponent(String(type))}/ccy/${encodeURIComponent(String(localCcy))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getRuleSchemeUsingGET(scheme, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getRuleSchemeUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} scheme
     * @param {?} ruleId
     * @param {?} policyId
     * @param {?} policy
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    updatePolicyBySchemeAndRuleIdUsingPUT(scheme, ruleId, policyId, policy, observe = 'body', reportProgress = false) {
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (policyId === null || policyId === undefined) {
            throw new Error('Required parameter policyId was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (policy === null || policy === undefined) {
            throw new Error('Required parameter policy was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(`${this.basePath}/pricing/schemes/${encodeURIComponent(String(scheme))}/rules/${encodeURIComponent(String(ruleId))}/policies/${encodeURIComponent(String(policyId))}`, policy, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcPricingControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcPricingControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
/* tslint:disable:no-unused-variable member-ordering */
class MtcTransferServiceControllerService {
    /**
     * @param {?} httpClient
     * @param {?} basePath
     * @param {?} configuration
     */
    constructor(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    /**
     * @param {?} consumes string[] mime-types
     * @return {?} true: consumes contains 'multipart/form-data', false: otherwise
     */
    canConsumeForm(consumes) {
        const /** @type {?} */ form = 'multipart/form-data';
        for (const /** @type {?} */ consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }
    /**
     * @param {?} idTransfer
     * @param {?} transferBlockRequest
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    blockTransferUsingPOST(idTransfer, transferBlockRequest, observe = 'body', reportProgress = false) {
        if (idTransfer === null || idTransfer === undefined) {
            throw new Error('Required parameter idTransfer was null or undefined when calling blockTransferUsingPOST.');
        }
        if (transferBlockRequest === null || transferBlockRequest === undefined) {
            throw new Error('Required parameter transferBlockRequest was null or undefined when calling blockTransferUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/transfer/${encodeURIComponent(String(idTransfer))}/block`, transferBlockRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?} creationNote
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    createTransferNoteUsingPOST(id, creationNote, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createTransferNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createTransferNoteUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/transfer/${encodeURIComponent(String(id))}/note`, creationNote, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    getTransferDetailsUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getTransferDetailsUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/transfer/${encodeURIComponent(String(id))}`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} idTransfer
     * @param {?} transferReleaseRequest
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    releaseTransferUsingPOST(idTransfer, transferReleaseRequest, observe = 'body', reportProgress = false) {
        if (idTransfer === null || idTransfer === undefined) {
            throw new Error('Required parameter idTransfer was null or undefined when calling releaseTransferUsingPOST.');
        }
        if (transferReleaseRequest === null || transferReleaseRequest === undefined) {
            throw new Error('Required parameter transferReleaseRequest was null or undefined when calling releaseTransferUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/transfer/${encodeURIComponent(String(idTransfer))}/release`, transferReleaseRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} id
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchNotesByTransferIdUsingGET(id, observe = 'body', reportProgress = false) {
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchNotesByTransferIdUsingGET.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        return this.httpClient.get(`${this.basePath}/transfer/${encodeURIComponent(String(id))}/note`, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
    /**
     * @param {?} filter
     * @param {?=} observe
     * @param {?=} reportProgress
     * @return {?}
     */
    searchTransfersUsingPOST(filter, observe = 'body', reportProgress = false) {
        if (filter === null || filter === undefined) {
            throw new Error('Required parameter filter was null or undefined when calling searchTransfersUsingPOST.');
        }
        let /** @type {?} */ headers = this.defaultHeaders;
        // authentication (Authorization) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        // to determine the Accept header
        let /** @type {?} */ httpHeaderAccepts = [
            '*/*'
        ];
        const /** @type {?} */ httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        // to determine the Content-Type header
        const /** @type {?} */ consumes = [
            'application/json'
        ];
        const /** @type {?} */ httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(`${this.basePath}/transfer/search`, filter, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    }
}
MtcTransferServiceControllerService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
MtcTransferServiceControllerService.ctorParameters = () => [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const APIS = [MtcAgentControllerService, MtcCustomerControllerService, MtcGsGeolocationControllerService, MtcNotesControllerService, MtcPricingControllerService, MtcTransferServiceControllerService];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var Agent;
(function (Agent) {
    Agent.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Inactive: /** @type {?} */ ('Inactive'),
        SignOut: /** @type {?} */ ('Sign_Out'),
        Pending: /** @type {?} */ ('Pending')
    };
    Agent.SubStatusEnum = {
        Debt: /** @type {?} */ ('Debt'),
        NotWorking: /** @type {?} */ ('Not_Working'),
        Compliance: /** @type {?} */ ('Compliance')
    };
})(Agent || (Agent = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var AgentSearchFilter;
(function (AgentSearchFilter) {
    AgentSearchFilter.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Inactive: /** @type {?} */ ('Inactive'),
        SignOut: /** @type {?} */ ('Sign_Out'),
        Pending: /** @type {?} */ ('Pending')
    };
})(AgentSearchFilter || (AgentSearchFilter = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var AgentSearchResult;
(function (AgentSearchResult) {
    AgentSearchResult.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Inactive: /** @type {?} */ ('Inactive'),
        SignOut: /** @type {?} */ ('Sign_Out'),
        Pending: /** @type {?} */ ('Pending')
    };
})(AgentSearchResult || (AgentSearchResult = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var Beneficiary;
(function (Beneficiary) {
    Beneficiary.SexEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
    Beneficiary.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Unactive: /** @type {?} */ ('Unactive'),
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
})(Beneficiary || (Beneficiary = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var ComposedTransferBasicInfo;
(function (ComposedTransferBasicInfo) {
    ComposedTransferBasicInfo.BlockedStatusEnum = {
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    ComposedTransferBasicInfo.ChannelEnum = {
        HomeTransfer: /** @type {?} */ ('HomeTransfer'),
        Agent: /** @type {?} */ ('Agent'),
        B2B: /** @type {?} */ ('B2B')
    };
    ComposedTransferBasicInfo.DeliveryModeEnum = {
        Cash: /** @type {?} */ ('Cash'),
        BankAccount: /** @type {?} */ ('BankAccount'),
        HomeDelivery: /** @type {?} */ ('HomeDelivery'),
        FamilySupport: /** @type {?} */ ('FamilySupport'),
        MobilePayment: /** @type {?} */ ('MobilePayment'),
        BillPayment: /** @type {?} */ ('BillPayment'),
        MutualContributionPayment: /** @type {?} */ ('MutualContributionPayment'),
        PrepaidCard: /** @type {?} */ ('PrepaidCard'),
        CashAnywhere: /** @type {?} */ ('CashAnywhere'),
        PrepaidCardAcquisition: /** @type {?} */ ('PrepaidCardAcquisition')
    };
    ComposedTransferBasicInfo.TransferStatusEnum = {
        Registered: /** @type {?} */ ('Registered'),
        Cancelled: /** @type {?} */ ('Cancelled'),
        CancelledImmediately: /** @type {?} */ ('CancelledImmediately'),
        Paid: /** @type {?} */ ('Paid'),
        PaymentRollback: /** @type {?} */ ('PaymentRollback')
    };
    ComposedTransferBasicInfo.TypeEnum = {
        Sending: /** @type {?} */ ('Sending'),
        Receiving: /** @type {?} */ ('Receiving')
    };
    ComposedTransferBasicInfo.WatchedStatusEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
})(ComposedTransferBasicInfo || (ComposedTransferBasicInfo = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CreateCustomerRequest;
(function (CreateCustomerRequest) {
    CreateCustomerRequest.SexEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
})(CreateCustomerRequest || (CreateCustomerRequest = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var Customer;
(function (Customer) {
    Customer.PeriodicityTypeEnum = {
        Occasional: /** @type {?} */ ('Occasional'),
        Habitual: /** @type {?} */ ('Habitual')
    };
    Customer.SexEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
    Customer.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Unactive: /** @type {?} */ ('Unactive'),
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    Customer.TypeEnum = {
        Local: /** @type {?} */ ('Local'),
        Remote: /** @type {?} */ ('Remote')
    };
    Customer.WatchedEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
})(Customer || (Customer = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var CustomerBasicData;
(function (CustomerBasicData) {
    CustomerBasicData.SexEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
    CustomerBasicData.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Unactive: /** @type {?} */ ('Unactive'),
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    CustomerBasicData.WatchedEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
})(CustomerBasicData || (CustomerBasicData = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var FiscalCode;
(function (FiscalCode) {
    FiscalCode.TypeEnum = {
        Auto: /** @type {?} */ ('Auto'),
        Manual: /** @type {?} */ ('Manual'),
        None: /** @type {?} */ ('None')
    };
})(FiscalCode || (FiscalCode = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var FullTransferDetails;
(function (FullTransferDetails) {
    FullTransferDetails.BlockStatusEnum = {
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    FullTransferDetails.ChannelEnum = {
        HomeTransfer: /** @type {?} */ ('HomeTransfer'),
        Agent: /** @type {?} */ ('Agent'),
        B2B: /** @type {?} */ ('B2B')
    };
    FullTransferDetails.DeliveryModeEnum = {
        Cash: /** @type {?} */ ('Cash'),
        BankAccount: /** @type {?} */ ('BankAccount'),
        HomeDelivery: /** @type {?} */ ('HomeDelivery'),
        FamilySupport: /** @type {?} */ ('FamilySupport'),
        MobilePayment: /** @type {?} */ ('MobilePayment'),
        BillPayment: /** @type {?} */ ('BillPayment'),
        MutualContributionPayment: /** @type {?} */ ('MutualContributionPayment'),
        PrepaidCard: /** @type {?} */ ('PrepaidCard'),
        CashAnywhere: /** @type {?} */ ('CashAnywhere'),
        PrepaidCardAcquisition: /** @type {?} */ ('PrepaidCardAcquisition')
    };
    FullTransferDetails.TransferStatusEnum = {
        Registered: /** @type {?} */ ('Registered'),
        Cancelled: /** @type {?} */ ('Cancelled'),
        CancelledImmediately: /** @type {?} */ ('CancelledImmediately'),
        Paid: /** @type {?} */ ('Paid'),
        PaymentRollback: /** @type {?} */ ('PaymentRollback')
    };
    FullTransferDetails.TypeEnum = {
        Sending: /** @type {?} */ ('Sending'),
        Receiving: /** @type {?} */ ('Receiving')
    };
    FullTransferDetails.WatchedStatusEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
})(FullTransferDetails || (FullTransferDetails = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var IdentityDocument;
(function (IdentityDocument) {
    IdentityDocument.TypeEnum = {
        PASS: /** @type {?} */ ('PASS'),
        DRVL: /** @type {?} */ ('DRVL'),
        EICD: /** @type {?} */ ('EICD'),
        NEIC: /** @type {?} */ ('NEIC'),
        OTHR: /** @type {?} */ ('OTHR'),
        NICD: /** @type {?} */ ('NICD'),
        RECD: /** @type {?} */ ('RECD'),
        GVID: /** @type {?} */ ('GVID'),
        STID: /** @type {?} */ ('STID'),
        GUNL: /** @type {?} */ ('GUNL'),
        DIPL: /** @type {?} */ ('DIPL'),
        CMPI: /** @type {?} */ ('CMPI'),
        IPOC: /** @type {?} */ ('IPOC'),
        CRLT: /** @type {?} */ ('CRLT'),
        CRSV: /** @type {?} */ ('CRSV'),
        CRLV: /** @type {?} */ ('CRLV'),
        CDRB: /** @type {?} */ ('CDRB'),
        LRPT: /** @type {?} */ ('LRPT'),
        EDRL: /** @type {?} */ ('EDRL'),
        RSVS: /** @type {?} */ ('RSVS'),
        BRDP: /** @type {?} */ ('BRDP'),
        CPFI: /** @type {?} */ ('CPFI'),
        NIFI: /** @type {?} */ ('NIFI'),
        LICI: /** @type {?} */ ('LICI'),
        LIEN: /** @type {?} */ ('LIEN'),
        CEID: /** @type {?} */ ('CEID')
    };
})(IdentityDocument || (IdentityDocument = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var Policy;
(function (Policy) {
    Policy.BasedOnEnum = {
        CustomerSourceAmount: /** @type {?} */ ('CustomerSourceAmount'),
        DestinationAmount: /** @type {?} */ ('DestinationAmount'),
        PartnerFees: /** @type {?} */ ('PartnerFees')
    };
})(Policy || (Policy = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var SearchCustomerRequest;
(function (SearchCustomerRequest) {
    SearchCustomerRequest.PeriodicityTypeEnum = {
        Occasional: /** @type {?} */ ('Occasional'),
        Habitual: /** @type {?} */ ('Habitual')
    };
})(SearchCustomerRequest || (SearchCustomerRequest = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var SearchCustomerResponse;
(function (SearchCustomerResponse) {
    SearchCustomerResponse.BlockedEnum = {
        Active: /** @type {?} */ ('Active'),
        Unactive: /** @type {?} */ ('Unactive'),
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
})(SearchCustomerResponse || (SearchCustomerResponse = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var SearchRequest;
(function (SearchRequest) {
    SearchRequest.BlockedStatusEnum = {
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    SearchRequest.WatchedStatusEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
    SearchRequest.StatusesEnum = {
        Registered: /** @type {?} */ ('Registered'),
        Cancelled: /** @type {?} */ ('Cancelled'),
        CancelledImmediately: /** @type {?} */ ('CancelledImmediately'),
        Paid: /** @type {?} */ ('Paid'),
        PaymentRollback: /** @type {?} */ ('PaymentRollback')
    };
    SearchRequest.ChannelEnum = {
        HomeTransfer: /** @type {?} */ ('HomeTransfer'),
        Agent: /** @type {?} */ ('Agent'),
        B2B: /** @type {?} */ ('B2B')
    };
})(SearchRequest || (SearchRequest = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var TransferCustomer;
(function (TransferCustomer) {
    TransferCustomer.GenderEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
})(TransferCustomer || (TransferCustomer = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * mtc-backoffice-api
 * MTC Backoffice Composite Api
 *
 * OpenAPI spec version: 0.1.0-SNAPSHOT
 * Contact: developers@greysystems.eu
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
var UpdateCustomerRequest;
(function (UpdateCustomerRequest) {
    UpdateCustomerRequest.SexEnum = {
        Male: /** @type {?} */ ('Male'),
        Female: /** @type {?} */ ('Female')
    };
    UpdateCustomerRequest.StatusEnum = {
        Active: /** @type {?} */ ('Active'),
        Unactive: /** @type {?} */ ('Unactive'),
        Blocked: /** @type {?} */ ('Blocked'),
        Unblocked: /** @type {?} */ ('Unblocked')
    };
    UpdateCustomerRequest.WatchedEnum = {
        Watched: /** @type {?} */ ('Watched'),
        Unwatched: /** @type {?} */ ('Unwatched')
    };
})(UpdateCustomerRequest || (UpdateCustomerRequest = {}));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ApiModule {
    /**
     * @param {?} parentModule
     * @param {?} http
     */
    constructor(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    /**
     * @param {?} configurationFactory
     * @return {?}
     */
    static forRoot(configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    }
}
ApiModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    MtcAgentControllerService,
                    MtcCustomerControllerService,
                    MtcGsGeolocationControllerService,
                    MtcNotesControllerService,
                    MtcPricingControllerService,
                    MtcTransferServiceControllerService
                ]
            },] },
];
/** @nocollapse */
ApiModule.ctorParameters = () => [
    { type: ApiModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    { type: HttpClient, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { APIS, MtcAgentControllerService, MtcCustomerControllerService, MtcGsGeolocationControllerService, MtcNotesControllerService, MtcPricingControllerService, MtcTransferServiceControllerService, Agent, AgentSearchFilter, AgentSearchResult, Beneficiary, ComposedTransferBasicInfo, CreateCustomerRequest, Customer, CustomerBasicData, FiscalCode, FullTransferDetails, IdentityDocument, Policy, SearchCustomerRequest, SearchCustomerResponse, SearchRequest, TransferCustomer, UpdateCustomerRequest, BASE_PATH, COLLECTION_FORMATS, Configuration, ApiModule };
//# sourceMappingURL=greysystems-angular-mtc-mtc-ms-backoffice-api.js.map
