import { __values, __extends } from 'tslib';
import { InjectionToken, Inject, Injectable, Optional, NgModule, SkipSelf } from '@angular/core';
import { HttpClient, HttpHeaders, HttpUrlEncodingCodec, HttpParams } from '@angular/common/http';

var BASE_PATH = new InjectionToken('basePath');
var COLLECTION_FORMATS = {
    'csv': ',',
    'tsv': '   ',
    'ssv': ' ',
    'pipes': '|'
};
var Configuration = /** @class */ (function () {
    function Configuration(configurationParameters) {
        if (configurationParameters === void 0) { configurationParameters = {}; }
        this.apiKeys = configurationParameters.apiKeys;
        this.username = configurationParameters.username;
        this.password = configurationParameters.password;
        this.accessToken = configurationParameters.accessToken;
        this.basePath = configurationParameters.basePath;
        this.withCredentials = configurationParameters.withCredentials;
    }
    Configuration.prototype.selectHeaderContentType = function (contentTypes) {
        var _this = this;
        if (contentTypes.length == 0) {
            return undefined;
        }
        var type = contentTypes.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return contentTypes[0];
        }
        return type;
    };
    Configuration.prototype.selectHeaderAccept = function (accepts) {
        var _this = this;
        if (accepts.length == 0) {
            return undefined;
        }
        var type = accepts.find(function (x) { return _this.isJsonMime(x); });
        if (type === undefined) {
            return accepts[0];
        }
        return type;
    };
    Configuration.prototype.isJsonMime = function (mime) {
        var jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
        return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
    };
    return Configuration;
}());
var MtcAgentControllerService = /** @class */ (function () {
    function MtcAgentControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcAgentControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                var consume = consumes_1_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
        var e_1, _a;
    };
    MtcAgentControllerService.prototype.bulkAgentBasicDataUsingGET = function (idAgentList, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (idAgentList === null || idAgentList === undefined) {
            throw new Error('Required parameter idAgentList was null or undefined when calling bulkAgentBasicDataUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.get(this.basePath + "/agents/basic", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcAgentControllerService.prototype.getAgentBasicDataUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getAgentBasicDataUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/agents/" + encodeURIComponent(String(id)) + "/basic", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcAgentControllerService.prototype.getAgentDetailDataUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getAgentDetailDataUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/agents/" + encodeURIComponent(String(id)) + "/detail", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcAgentControllerService.prototype.searchAgentsUsingFilterUsingPOST = function (filter, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (filter === null || filter === undefined) {
            throw new Error('Required parameter filter was null or undefined when calling searchAgentsUsingFilterUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/agents/search", filter, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcAgentControllerService;
}());
MtcAgentControllerService.decorators = [
    { type: Injectable },
];
MtcAgentControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var CustomHttpUrlEncodingCodec = /** @class */ (function (_super) {
    __extends(CustomHttpUrlEncodingCodec, _super);
    function CustomHttpUrlEncodingCodec() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomHttpUrlEncodingCodec.prototype.encodeKey = function (k) {
        k = _super.prototype.encodeKey.call(this, k);
        return k.replace(/\+/gi, '%2B');
    };
    CustomHttpUrlEncodingCodec.prototype.encodeValue = function (v) {
        v = _super.prototype.encodeValue.call(this, v);
        return v.replace(/\+/gi, '%2B');
    };
    return CustomHttpUrlEncodingCodec;
}(HttpUrlEncodingCodec));
var MtcCustomerControllerService = /** @class */ (function () {
    function MtcCustomerControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcCustomerControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_2 = __values(consumes), consumes_2_1 = consumes_2.next(); !consumes_2_1.done; consumes_2_1 = consumes_2.next()) {
                var consume = consumes_2_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (consumes_2_1 && !consumes_2_1.done && (_a = consumes_2.return)) _a.call(consumes_2);
            }
            finally { if (e_2) throw e_2.error; }
        }
        return false;
        var e_2, _a;
    };
    MtcCustomerControllerService.prototype.createCustomerIdentityDocumentFileUsingPOST = function (id, idDoc, file, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        if (file === null || file === undefined) {
            throw new Error('Required parameter file was null or undefined when calling createCustomerIdentityDocumentFileUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'multipart/form-data'
        ];
        var canConsumeForm = this.canConsumeForm(consumes);
        var formParams;
        var useForm = false;
        var convertFormParamsToString = false;
        useForm = canConsumeForm;
        if (useForm) {
            formParams = new FormData();
        }
        else {
            formParams = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        }
        if (file !== undefined) {
            formParams = formParams.append('file', (file)) || formParams;
        }
        return this.httpClient.post(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc/" + encodeURIComponent(String(idDoc)) + "/file", convertFormParamsToString ? formParams.toString() : formParams, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.createCustomerIdentityDocumentUsingPOST = function (id, identityDocumentDetail, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerIdentityDocumentUsingPOST.');
        }
        if (identityDocumentDetail === null || identityDocumentDetail === undefined) {
            throw new Error('Required parameter identityDocumentDetail was null or undefined when calling createCustomerIdentityDocumentUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc", identityDocumentDetail, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.createCustomerNoteUsingPOST = function (id, creationNote, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createCustomerNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createCustomerNoteUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/note", creationNote, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.createCustomerUsingPOST = function (request, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling createCustomerUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/customer", request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerEssentialDataByIdsUsingGET = function (ids, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (ids === null || ids === undefined) {
            throw new Error('Required parameter ids was null or undefined when calling getCustomerEssentialDataByIdsUsingGET.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (ids) {
            ids.forEach(function (element) {
                queryParameters = queryParameters.append('ids', (element));
            });
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer" + encodeURIComponent(String(ids)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerEssentialDataUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerEssentialDataUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/essential", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerFullDataUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerFullDataUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/full", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerIdentityDocumentByIdUsingGET = function (id, idDoc, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentByIdUsingGET.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling getCustomerIdentityDocumentByIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc/" + encodeURIComponent(String(idDoc)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerIdentityDocumentFileByIdUsingGET = function (id, idDoc, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentFileByIdUsingGET.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling getCustomerIdentityDocumentFileByIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc/" + encodeURIComponent(String(idDoc)) + "/file", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.getCustomerIdentityDocumentsUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCustomerIdentityDocumentsUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.searchBeneficiariesByOwnerUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchBeneficiariesByOwnerUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/beneficiaries", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.searchCustomersUsingPOST = function (request, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling searchCustomersUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/customer/search", request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.searchNotesByCustomerIdUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchNotesByCustomerIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/note", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.updateCustomerIdentityDocumentUsingPUT = function (id, idDoc, identityDocumentDetail, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        if (idDoc === null || idDoc === undefined) {
            throw new Error('Required parameter idDoc was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        if (identityDocumentDetail === null || identityDocumentDetail === undefined) {
            throw new Error('Required parameter identityDocumentDetail was null or undefined when calling updateCustomerIdentityDocumentUsingPUT.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.basePath + "/customer/" + encodeURIComponent(String(id)) + "/idDoc/" + encodeURIComponent(String(idDoc)), identityDocumentDetail, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcCustomerControllerService.prototype.updateCustomerUsingPUT = function (id, request, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling updateCustomerUsingPUT.');
        }
        if (request === null || request === undefined) {
            throw new Error('Required parameter request was null or undefined when calling updateCustomerUsingPUT.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.basePath + "/customer/" + encodeURIComponent(String(id)), request, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcCustomerControllerService;
}());
MtcCustomerControllerService.decorators = [
    { type: Injectable },
];
MtcCustomerControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var MtcGsGeolocationControllerService = /** @class */ (function () {
    function MtcGsGeolocationControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcGsGeolocationControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_3 = __values(consumes), consumes_3_1 = consumes_3.next(); !consumes_3_1.done; consumes_3_1 = consumes_3.next()) {
                var consume = consumes_3_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (consumes_3_1 && !consumes_3_1.done && (_a = consumes_3.return)) _a.call(consumes_3);
            }
            finally { if (e_3) throw e_3.error; }
        }
        return false;
        var e_3, _a;
    };
    MtcGsGeolocationControllerService.prototype.getCityByIdUsingGET = function (idCity, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (idCity === null || idCity === undefined) {
            throw new Error('Required parameter idCity was null or undefined when calling getCityByIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/geo/city/" + encodeURIComponent(String(idCity)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcGsGeolocationControllerService.prototype.searchCityByCountryAndNameUsingGET = function (country, cityName, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (country === null || country === undefined) {
            throw new Error('Required parameter country was null or undefined when calling searchCityByCountryAndNameUsingGET.');
        }
        if (cityName === null || cityName === undefined) {
            throw new Error('Required parameter cityName was null or undefined when calling searchCityByCountryAndNameUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/geo/city/" + encodeURIComponent(String(country)) + "/" + encodeURIComponent(String(cityName)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcGsGeolocationControllerService;
}());
MtcGsGeolocationControllerService.decorators = [
    { type: Injectable },
];
MtcGsGeolocationControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var MtcNotesControllerService = /** @class */ (function () {
    function MtcNotesControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcNotesControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_4 = __values(consumes), consumes_4_1 = consumes_4.next(); !consumes_4_1.done; consumes_4_1 = consumes_4.next()) {
                var consume = consumes_4_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (consumes_4_1 && !consumes_4_1.done && (_a = consumes_4.return)) _a.call(consumes_4);
            }
            finally { if (e_4) throw e_4.error; }
        }
        return false;
        var e_4, _a;
    };
    MtcNotesControllerService.prototype.createNoteUsingPOST = function (owner, creationNote, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (owner === null || owner === undefined) {
            throw new Error('Required parameter owner was null or undefined when calling createNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createNoteUsingPOST.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (owner !== undefined && owner !== null) {
            queryParameters = queryParameters.set('owner', (owner));
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/note" + encodeURIComponent(String(owner)), creationNote, {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcNotesControllerService.prototype.searchNotesByOwnerUsingGET = function (owner, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (owner === null || owner === undefined) {
            throw new Error('Required parameter owner was null or undefined when calling searchNotesByOwnerUsingGET.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (owner !== undefined && owner !== null) {
            queryParameters = queryParameters.set('owner', (owner));
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/note/search", {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcNotesControllerService;
}());
MtcNotesControllerService.decorators = [
    { type: Injectable },
];
MtcNotesControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var MtcPricingControllerService = /** @class */ (function () {
    function MtcPricingControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcPricingControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_5 = __values(consumes), consumes_5_1 = consumes_5.next(); !consumes_5_1.done; consumes_5_1 = consumes_5.next()) {
                var consume = consumes_5_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (consumes_5_1 && !consumes_5_1.done && (_a = consumes_5.return)) _a.call(consumes_5);
            }
            finally { if (e_5) throw e_5.error; }
        }
        return false;
        var e_5, _a;
    };
    MtcPricingControllerService.prototype.addCountryZoneMembersBySchemeAndIdUsingPOST = function (scheme, id, iso, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        if (iso === null || iso === undefined) {
            throw new Error('Required parameter iso was null or undefined when calling addCountryZoneMembersBySchemeAndIdUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.post(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/country-zones/" + encodeURIComponent(String(id)) + "/members/" + encodeURIComponent(String(iso)), null, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.createPolicyBySchemeAndRuleIdUsingPOST = function (scheme, ruleId, policy, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        if (policy === null || policy === undefined) {
            throw new Error('Required parameter policy was null or undefined when calling createPolicyBySchemeAndRuleIdUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/" + encodeURIComponent(String(ruleId)) + "/policies", policy, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.createRuleBySchemeAndTypeAndCcyUsingPOST = function (scheme, type, localCcy, createRule, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (localCcy === null || localCcy === undefined) {
            throw new Error('Required parameter localCcy was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        if (createRule === null || createRule === undefined) {
            throw new Error('Required parameter createRule was null or undefined when calling createRuleBySchemeAndTypeAndCcyUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/types/" + encodeURIComponent(String(type)) + "/ccy/" + encodeURIComponent(String(localCcy)), createRule, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.deleteCountryZoneMembersBySchemeAndIdUsingDELETE = function (scheme, id, iso, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        if (iso === null || iso === undefined) {
            throw new Error('Required parameter iso was null or undefined when calling deleteCountryZoneMembersBySchemeAndIdUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/country-zones/" + encodeURIComponent(String(id)) + "/members/" + encodeURIComponent(String(iso)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.deletePolicyBySchemeAndIdUsingDELETE = function (scheme, ruleId, policyId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        if (policyId === null || policyId === undefined) {
            throw new Error('Required parameter policyId was null or undefined when calling deletePolicyBySchemeAndIdUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/" + encodeURIComponent(String(ruleId)) + "/policies/" + encodeURIComponent(String(policyId)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.deleteRuleBySchemaAndIdUsingDELETE = function (scheme, id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling deleteRuleBySchemaAndIdUsingDELETE.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling deleteRuleBySchemaAndIdUsingDELETE.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.delete(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getCountryZoneBySchemeAndIdUsingGET = function (scheme, id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZoneBySchemeAndIdUsingGET.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCountryZoneBySchemeAndIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/country-zones/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getCountryZoneMembersByBySchemeAndIdUsingGET = function (scheme, id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZoneMembersByBySchemeAndIdUsingGET.');
        }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getCountryZoneMembersByBySchemeAndIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/country-zones/" + encodeURIComponent(String(id)) + "/members", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getCountryZonesBySchemeAndTypeOfRuleUsingGET = function (scheme, type, internal, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getCountryZonesBySchemeAndTypeOfRuleUsingGET.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling getCountryZonesBySchemeAndTypeOfRuleUsingGET.');
        }
        var queryParameters = new HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
        if (internal !== undefined && internal !== null) {
            queryParameters = queryParameters.set('internal', (internal));
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/country-zones/rule-type/" + encodeURIComponent(String(type)) + encodeURIComponent(String(internal)), {
            params: queryParameters,
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getPoliciesBySchemeAndRuleIdUsingGET = function (scheme, ruleId, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getPoliciesBySchemeAndRuleIdUsingGET.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling getPoliciesBySchemeAndRuleIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/" + encodeURIComponent(String(ruleId)) + "/policies", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getRuleBySchemeAnRuleTypeAndCcyUsingGET = function (scheme, type, localCcy, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        if (type === null || type === undefined) {
            throw new Error('Required parameter type was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        if (localCcy === null || localCcy === undefined) {
            throw new Error('Required parameter localCcy was null or undefined when calling getRuleBySchemeAnRuleTypeAndCcyUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/types/" + encodeURIComponent(String(type)) + "/ccy/" + encodeURIComponent(String(localCcy)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.getRuleSchemeUsingGET = function (scheme, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling getRuleSchemeUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcPricingControllerService.prototype.updatePolicyBySchemeAndRuleIdUsingPUT = function (scheme, ruleId, policyId, policy, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (scheme === null || scheme === undefined) {
            throw new Error('Required parameter scheme was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (ruleId === null || ruleId === undefined) {
            throw new Error('Required parameter ruleId was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (policyId === null || policyId === undefined) {
            throw new Error('Required parameter policyId was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        if (policy === null || policy === undefined) {
            throw new Error('Required parameter policy was null or undefined when calling updatePolicyBySchemeAndRuleIdUsingPUT.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.put(this.basePath + "/pricing/schemes/" + encodeURIComponent(String(scheme)) + "/rules/" + encodeURIComponent(String(ruleId)) + "/policies/" + encodeURIComponent(String(policyId)), policy, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcPricingControllerService;
}());
MtcPricingControllerService.decorators = [
    { type: Injectable },
];
MtcPricingControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var MtcTransferServiceControllerService = /** @class */ (function () {
    function MtcTransferServiceControllerService(httpClient, basePath, configuration) {
        this.httpClient = httpClient;
        this.basePath = 'https://mtc-ms-backoffice-api';
        this.defaultHeaders = new HttpHeaders();
        this.configuration = new Configuration();
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }
    MtcTransferServiceControllerService.prototype.canConsumeForm = function (consumes) {
        var form = 'multipart/form-data';
        try {
            for (var consumes_6 = __values(consumes), consumes_6_1 = consumes_6.next(); !consumes_6_1.done; consumes_6_1 = consumes_6.next()) {
                var consume = consumes_6_1.value;
                if (form === consume) {
                    return true;
                }
            }
        }
        catch (e_6_1) { e_6 = { error: e_6_1 }; }
        finally {
            try {
                if (consumes_6_1 && !consumes_6_1.done && (_a = consumes_6.return)) _a.call(consumes_6);
            }
            finally { if (e_6) throw e_6.error; }
        }
        return false;
        var e_6, _a;
    };
    MtcTransferServiceControllerService.prototype.blockTransferUsingPOST = function (idTransfer, transferBlockRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (idTransfer === null || idTransfer === undefined) {
            throw new Error('Required parameter idTransfer was null or undefined when calling blockTransferUsingPOST.');
        }
        if (transferBlockRequest === null || transferBlockRequest === undefined) {
            throw new Error('Required parameter transferBlockRequest was null or undefined when calling blockTransferUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/transfer/" + encodeURIComponent(String(idTransfer)) + "/block", transferBlockRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcTransferServiceControllerService.prototype.createTransferNoteUsingPOST = function (id, creationNote, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling createTransferNoteUsingPOST.');
        }
        if (creationNote === null || creationNote === undefined) {
            throw new Error('Required parameter creationNote was null or undefined when calling createTransferNoteUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/transfer/" + encodeURIComponent(String(id)) + "/note", creationNote, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcTransferServiceControllerService.prototype.getTransferDetailsUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling getTransferDetailsUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/transfer/" + encodeURIComponent(String(id)), {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcTransferServiceControllerService.prototype.releaseTransferUsingPOST = function (idTransfer, transferReleaseRequest, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (idTransfer === null || idTransfer === undefined) {
            throw new Error('Required parameter idTransfer was null or undefined when calling releaseTransferUsingPOST.');
        }
        if (transferReleaseRequest === null || transferReleaseRequest === undefined) {
            throw new Error('Required parameter transferReleaseRequest was null or undefined when calling releaseTransferUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/transfer/" + encodeURIComponent(String(idTransfer)) + "/release", transferReleaseRequest, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcTransferServiceControllerService.prototype.searchNotesByTransferIdUsingGET = function (id, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (id === null || id === undefined) {
            throw new Error('Required parameter id was null or undefined when calling searchNotesByTransferIdUsingGET.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        return this.httpClient.get(this.basePath + "/transfer/" + encodeURIComponent(String(id)) + "/note", {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    MtcTransferServiceControllerService.prototype.searchTransfersUsingPOST = function (filter, observe, reportProgress) {
        if (observe === void 0) { observe = 'body'; }
        if (reportProgress === void 0) { reportProgress = false; }
        if (filter === null || filter === undefined) {
            throw new Error('Required parameter filter was null or undefined when calling searchTransfersUsingPOST.');
        }
        var headers = this.defaultHeaders;
        if (this.configuration.apiKeys && this.configuration.apiKeys["Authorization"]) {
            headers = headers.set('Authorization', this.configuration.apiKeys["Authorization"]);
        }
        var httpHeaderAccepts = [
            '*/*'
        ];
        var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }
        var consumes = [
            'application/json'
        ];
        var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
        if (httpContentTypeSelected != undefined) {
            headers = headers.set('Content-Type', httpContentTypeSelected);
        }
        return this.httpClient.post(this.basePath + "/transfer/search", filter, {
            withCredentials: this.configuration.withCredentials,
            headers: headers,
            observe: observe,
            reportProgress: reportProgress
        });
    };
    return MtcTransferServiceControllerService;
}());
MtcTransferServiceControllerService.decorators = [
    { type: Injectable },
];
MtcTransferServiceControllerService.ctorParameters = function () { return [
    { type: HttpClient, },
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [BASE_PATH,] },] },
    { type: Configuration, decorators: [{ type: Optional },] },
]; };
var APIS = [MtcAgentControllerService, MtcCustomerControllerService, MtcGsGeolocationControllerService, MtcNotesControllerService, MtcPricingControllerService, MtcTransferServiceControllerService];
var Agent;
(function (Agent) {
    Agent.StatusEnum = {
        Active: ('Active'),
        Inactive: ('Inactive'),
        SignOut: ('Sign_Out'),
        Pending: ('Pending')
    };
    Agent.SubStatusEnum = {
        Debt: ('Debt'),
        NotWorking: ('Not_Working'),
        Compliance: ('Compliance')
    };
})(Agent || (Agent = {}));
var AgentSearchFilter;
(function (AgentSearchFilter) {
    AgentSearchFilter.StatusEnum = {
        Active: ('Active'),
        Inactive: ('Inactive'),
        SignOut: ('Sign_Out'),
        Pending: ('Pending')
    };
})(AgentSearchFilter || (AgentSearchFilter = {}));
var AgentSearchResult;
(function (AgentSearchResult) {
    AgentSearchResult.StatusEnum = {
        Active: ('Active'),
        Inactive: ('Inactive'),
        SignOut: ('Sign_Out'),
        Pending: ('Pending')
    };
})(AgentSearchResult || (AgentSearchResult = {}));
var Beneficiary;
(function (Beneficiary) {
    Beneficiary.SexEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
    Beneficiary.StatusEnum = {
        Active: ('Active'),
        Unactive: ('Unactive'),
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
})(Beneficiary || (Beneficiary = {}));
var ComposedTransferBasicInfo;
(function (ComposedTransferBasicInfo) {
    ComposedTransferBasicInfo.BlockedStatusEnum = {
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    ComposedTransferBasicInfo.ChannelEnum = {
        HomeTransfer: ('HomeTransfer'),
        Agent: ('Agent'),
        B2B: ('B2B')
    };
    ComposedTransferBasicInfo.DeliveryModeEnum = {
        Cash: ('Cash'),
        BankAccount: ('BankAccount'),
        HomeDelivery: ('HomeDelivery'),
        FamilySupport: ('FamilySupport'),
        MobilePayment: ('MobilePayment'),
        BillPayment: ('BillPayment'),
        MutualContributionPayment: ('MutualContributionPayment'),
        PrepaidCard: ('PrepaidCard'),
        CashAnywhere: ('CashAnywhere'),
        PrepaidCardAcquisition: ('PrepaidCardAcquisition')
    };
    ComposedTransferBasicInfo.TransferStatusEnum = {
        Registered: ('Registered'),
        Cancelled: ('Cancelled'),
        CancelledImmediately: ('CancelledImmediately'),
        Paid: ('Paid'),
        PaymentRollback: ('PaymentRollback')
    };
    ComposedTransferBasicInfo.TypeEnum = {
        Sending: ('Sending'),
        Receiving: ('Receiving')
    };
    ComposedTransferBasicInfo.WatchedStatusEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
})(ComposedTransferBasicInfo || (ComposedTransferBasicInfo = {}));
var CreateCustomerRequest;
(function (CreateCustomerRequest) {
    CreateCustomerRequest.SexEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
})(CreateCustomerRequest || (CreateCustomerRequest = {}));
var Customer;
(function (Customer) {
    Customer.PeriodicityTypeEnum = {
        Occasional: ('Occasional'),
        Habitual: ('Habitual')
    };
    Customer.SexEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
    Customer.StatusEnum = {
        Active: ('Active'),
        Unactive: ('Unactive'),
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    Customer.TypeEnum = {
        Local: ('Local'),
        Remote: ('Remote')
    };
    Customer.WatchedEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
})(Customer || (Customer = {}));
var CustomerBasicData;
(function (CustomerBasicData) {
    CustomerBasicData.SexEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
    CustomerBasicData.StatusEnum = {
        Active: ('Active'),
        Unactive: ('Unactive'),
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    CustomerBasicData.WatchedEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
})(CustomerBasicData || (CustomerBasicData = {}));
var FiscalCode;
(function (FiscalCode) {
    FiscalCode.TypeEnum = {
        Auto: ('Auto'),
        Manual: ('Manual'),
        None: ('None')
    };
})(FiscalCode || (FiscalCode = {}));
var FullTransferDetails;
(function (FullTransferDetails) {
    FullTransferDetails.BlockStatusEnum = {
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    FullTransferDetails.ChannelEnum = {
        HomeTransfer: ('HomeTransfer'),
        Agent: ('Agent'),
        B2B: ('B2B')
    };
    FullTransferDetails.DeliveryModeEnum = {
        Cash: ('Cash'),
        BankAccount: ('BankAccount'),
        HomeDelivery: ('HomeDelivery'),
        FamilySupport: ('FamilySupport'),
        MobilePayment: ('MobilePayment'),
        BillPayment: ('BillPayment'),
        MutualContributionPayment: ('MutualContributionPayment'),
        PrepaidCard: ('PrepaidCard'),
        CashAnywhere: ('CashAnywhere'),
        PrepaidCardAcquisition: ('PrepaidCardAcquisition')
    };
    FullTransferDetails.TransferStatusEnum = {
        Registered: ('Registered'),
        Cancelled: ('Cancelled'),
        CancelledImmediately: ('CancelledImmediately'),
        Paid: ('Paid'),
        PaymentRollback: ('PaymentRollback')
    };
    FullTransferDetails.TypeEnum = {
        Sending: ('Sending'),
        Receiving: ('Receiving')
    };
    FullTransferDetails.WatchedStatusEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
})(FullTransferDetails || (FullTransferDetails = {}));
var IdentityDocument;
(function (IdentityDocument) {
    IdentityDocument.TypeEnum = {
        PASS: ('PASS'),
        DRVL: ('DRVL'),
        EICD: ('EICD'),
        NEIC: ('NEIC'),
        OTHR: ('OTHR'),
        NICD: ('NICD'),
        RECD: ('RECD'),
        GVID: ('GVID'),
        STID: ('STID'),
        GUNL: ('GUNL'),
        DIPL: ('DIPL'),
        CMPI: ('CMPI'),
        IPOC: ('IPOC'),
        CRLT: ('CRLT'),
        CRSV: ('CRSV'),
        CRLV: ('CRLV'),
        CDRB: ('CDRB'),
        LRPT: ('LRPT'),
        EDRL: ('EDRL'),
        RSVS: ('RSVS'),
        BRDP: ('BRDP'),
        CPFI: ('CPFI'),
        NIFI: ('NIFI'),
        LICI: ('LICI'),
        LIEN: ('LIEN'),
        CEID: ('CEID')
    };
})(IdentityDocument || (IdentityDocument = {}));
var Policy;
(function (Policy) {
    Policy.BasedOnEnum = {
        CustomerSourceAmount: ('CustomerSourceAmount'),
        DestinationAmount: ('DestinationAmount'),
        PartnerFees: ('PartnerFees')
    };
})(Policy || (Policy = {}));
var SearchCustomerRequest;
(function (SearchCustomerRequest) {
    SearchCustomerRequest.PeriodicityTypeEnum = {
        Occasional: ('Occasional'),
        Habitual: ('Habitual')
    };
})(SearchCustomerRequest || (SearchCustomerRequest = {}));
var SearchCustomerResponse;
(function (SearchCustomerResponse) {
    SearchCustomerResponse.BlockedEnum = {
        Active: ('Active'),
        Unactive: ('Unactive'),
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
})(SearchCustomerResponse || (SearchCustomerResponse = {}));
var SearchRequest;
(function (SearchRequest) {
    SearchRequest.BlockedStatusEnum = {
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    SearchRequest.WatchedStatusEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
    SearchRequest.StatusesEnum = {
        Registered: ('Registered'),
        Cancelled: ('Cancelled'),
        CancelledImmediately: ('CancelledImmediately'),
        Paid: ('Paid'),
        PaymentRollback: ('PaymentRollback')
    };
    SearchRequest.ChannelEnum = {
        HomeTransfer: ('HomeTransfer'),
        Agent: ('Agent'),
        B2B: ('B2B')
    };
})(SearchRequest || (SearchRequest = {}));
var TransferCustomer;
(function (TransferCustomer) {
    TransferCustomer.GenderEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
})(TransferCustomer || (TransferCustomer = {}));
var UpdateCustomerRequest;
(function (UpdateCustomerRequest) {
    UpdateCustomerRequest.SexEnum = {
        Male: ('Male'),
        Female: ('Female')
    };
    UpdateCustomerRequest.StatusEnum = {
        Active: ('Active'),
        Unactive: ('Unactive'),
        Blocked: ('Blocked'),
        Unblocked: ('Unblocked')
    };
    UpdateCustomerRequest.WatchedEnum = {
        Watched: ('Watched'),
        Unwatched: ('Unwatched')
    };
})(UpdateCustomerRequest || (UpdateCustomerRequest = {}));
var ApiModule = /** @class */ (function () {
    function ApiModule(parentModule, http) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
        }
        if (!http) {
            throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                'See also https://github.com/angular/angular/issues/20575');
        }
    }
    ApiModule.forRoot = function (configurationFactory) {
        return {
            ngModule: ApiModule,
            providers: [{ provide: Configuration, useFactory: configurationFactory }]
        };
    };
    return ApiModule;
}());
ApiModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    MtcAgentControllerService,
                    MtcCustomerControllerService,
                    MtcGsGeolocationControllerService,
                    MtcNotesControllerService,
                    MtcPricingControllerService,
                    MtcTransferServiceControllerService
                ]
            },] },
];
ApiModule.ctorParameters = function () { return [
    { type: ApiModule, decorators: [{ type: Optional }, { type: SkipSelf },] },
    { type: HttpClient, decorators: [{ type: Optional },] },
]; };

export { APIS, MtcAgentControllerService, MtcCustomerControllerService, MtcGsGeolocationControllerService, MtcNotesControllerService, MtcPricingControllerService, MtcTransferServiceControllerService, Agent, AgentSearchFilter, AgentSearchResult, Beneficiary, ComposedTransferBasicInfo, CreateCustomerRequest, Customer, CustomerBasicData, FiscalCode, FullTransferDetails, IdentityDocument, Policy, SearchCustomerRequest, SearchCustomerResponse, SearchRequest, TransferCustomer, UpdateCustomerRequest, BASE_PATH, COLLECTION_FORMATS, Configuration, ApiModule };
//# sourceMappingURL=greysystems-angular-mtc-mtc-ms-backoffice-api.js.map
